<?php
/**
 * About Section
 *
 * @package Travellable
 */

$wp_customize->add_section(
	'travellable_about_section',
	array(
		'panel' => 'travellable_front_page_options',
		'title' => esc_html__( 'About Section', 'travellable' ),
	)
);

// About Section - Enable Section.
$wp_customize->add_setting(
	'travellable_enable_about_section',
	array(
		'default'           => false,
		'sanitize_callback' => 'travellable_sanitize_switch',
	)
);

$wp_customize->add_control(
	new Travellable_Toggle_Switch_Custom_Control(
		$wp_customize,
		'travellable_enable_about_section',
		array(
			'label'    => esc_html__( 'Enable About Section', 'travellable' ),
			'section'  => 'travellable_about_section',
			'settings' => 'travellable_enable_about_section',
		)
	)
);

if ( isset( $wp_customize->selective_refresh ) ) {
	$wp_customize->selective_refresh->add_partial(
		'travellable_enable_about_section',
		array(
			'selector' => '#travellable_about_section .section-link',
			'settings' => 'travellable_enable_about_section',
		)
	);
}

// About Section - Content Type.
$wp_customize->add_setting(
	'travellable_about_content_type',
	array(
		'default'           => 'page',
		'sanitize_callback' => 'travellable_sanitize_select',
	)
);

$wp_customize->add_control(
	'travellable_about_content_type',
	array(
		'label'           => esc_html__( 'Select Content Type', 'travellable' ),
		'section'         => 'travellable_about_section',
		'settings'        => 'travellable_about_content_type',
		'type'            => 'select',
		'active_callback' => 'travellable_is_about_section_enabled',
		'choices'         => array(
			'page' => esc_html__( 'Page', 'travellable' ),
			'post' => esc_html__( 'Post', 'travellable' ),
		),
	)
);

// About Section - Content Type Post.
$wp_customize->add_setting(
	'travellable_about_content_post',
	array(
		'sanitize_callback' => 'absint',
	)
);

$wp_customize->add_control(
	'travellable_about_content_post',
	array(
		'section'         => 'travellable_about_section',
		'settings'        => 'travellable_about_content_post',
		'label'           => esc_html__( 'Select Post', 'travellable' ),
		'active_callback' => 'travellable_is_about_section_and_content_type_post_enabled',
		'type'            => 'select',
		'choices'         => travellable_get_post_choices(),
	)
);

// About Section - Content Type Page.
$wp_customize->add_setting(
	'travellable_about_content_page',
	array(
		'sanitize_callback' => 'absint',
	)
);

$wp_customize->add_control(
	'travellable_about_content_page',
	array(
		'label'           => esc_html__( 'Select Page', 'travellable' ),
		'section'         => 'travellable_about_section',
		'settings'        => 'travellable_about_content_page',
		'active_callback' => 'travellable_is_about_section_and_content_type_page_enabled',
		'type'            => 'select',
		'choices'         => travellable_get_page_choices(),
	)
);

// About Section - Button Label.
$wp_customize->add_setting(
	'travellable_about_button_label',
	array(
		'default'           => __( 'More about us', 'travellable' ),
		'sanitize_callback' => 'sanitize_text_field',
		'transport'         => 'refresh',
	)
);

$wp_customize->add_control(
	'travellable_about_button_label',
	array(
		'label'           => esc_html__( 'Button Label', 'travellable' ),
		'section'         => 'travellable_about_section',
		'settings'        => 'travellable_about_button_label',
		'type'            => 'text',
		'active_callback' => 'travellable_is_about_section_enabled',
	)
);
