<?php
/**
 * Popular Destination
 *
 * @package Travellable
 */

$wp_customize->add_section(
	'travellable_popular_destination_section',
	array(
		'panel' => 'travellable_front_page_options',
		'title' => esc_html__( 'Popular Destination', 'travellable' ),
	)
);

// Popular Destination - Enable Section.
$wp_customize->add_setting(
	'travellable_enable_popular_destination_section',
	array(
		'default'           => false,
		'sanitize_callback' => 'travellable_sanitize_switch',
	)
);

$wp_customize->add_control(
	new Travellable_Toggle_Switch_Custom_Control(
		$wp_customize,
		'travellable_enable_popular_destination_section',
		array(
			'label'    => esc_html__( 'Enable Popular Destination', 'travellable' ),
			'section'  => 'travellable_popular_destination_section',
			'settings' => 'travellable_enable_popular_destination_section',
		)
	)
);

if ( isset( $wp_customize->selective_refresh ) ) {
	$wp_customize->selective_refresh->add_partial(
		'travellable_enable_popular_destination_section',
		array(
			'selector' => '#travellable_popular_destination_section .section-link',
			'settings' => 'travellable_enable_popular_destination_section',
		)
	);
}

// Popular Destination - Section Title.
$wp_customize->add_setting(
	'travellable_popular_destination_title',
	array(
		'default'           => __( 'Destinations', 'travellable' ),
		'sanitize_callback' => 'sanitize_text_field',
	)
);

$wp_customize->add_control(
	'travellable_popular_destination_title',
	array(
		'label'           => esc_html__( 'Section Title', 'travellable' ),
		'section'         => 'travellable_popular_destination_section',
		'settings'        => 'travellable_popular_destination_title',
		'type'            => 'text',
		'active_callback' => 'travellable_is_popular_destination_section_enabled',
	)
);

// Popular Destination - Content Type.
$wp_customize->add_setting(
	'travellable_popular_destination_content_type',
	array(
		'default'           => 'page',
		'sanitize_callback' => 'travellable_sanitize_select',
	)
);

$wp_customize->add_control(
	'travellable_popular_destination_content_type',
	array(
		'label'           => esc_html__( 'Select Content Type', 'travellable' ),
		'section'         => 'travellable_popular_destination_section',
		'settings'        => 'travellable_popular_destination_content_type',
		'type'            => 'select',
		'active_callback' => 'travellable_is_popular_destination_section_enabled',
		'choices'         => travellable_get_popular_destination_content_type_choices(),
	)
);

// List out selected number of fields.
for ( $i = 1; $i <= 5; $i++ ) {
	// Popular Destination - Select Post.
	$wp_customize->add_setting(
		'travellable_popular_destination_content_post_' . $i,
		array(
			'sanitize_callback' => 'absint',
		)
	);

	$wp_customize->add_control(
		'travellable_popular_destination_content_post_' . $i,
		array(
			'label'           => esc_html__( 'Select Post ', 'travellable' ) . $i,
			'section'         => 'travellable_popular_destination_section',
			'settings'        => 'travellable_popular_destination_content_post_' . $i,
			'active_callback' => 'travellable_is_popular_destination_section_and_content_type_post_enabled',
			'type'            => 'select',
			'choices'         => travellable_get_post_choices(),
		)
	);

	// Popular Destination - Select Page.
	$wp_customize->add_setting(
		'travellable_popular_destination_content_page_' . $i,
		array(
			'sanitize_callback' => 'absint',
		)
	);

	$wp_customize->add_control(
		'travellable_popular_destination_content_page_' . $i,
		array(
			'label'           => esc_html__( 'Select Page ', 'travellable' ) . $i,
			'section'         => 'travellable_popular_destination_section',
			'settings'        => 'travellable_popular_destination_content_page_' . $i,
			'active_callback' => 'travellable_is_popular_destination_section_and_content_type_page_enabled',
			'type'            => 'select',
			'choices'         => travellable_get_page_choices(),
		)
	);

	// Popular Destination - Select Trip.
	$wp_customize->add_setting(
		'travellable_popular_destination_content_trip_' . $i,
		array(
			'sanitize_callback' => 'absint',
		)
	);

	$wp_customize->add_control(
		'travellable_popular_destination_content_trip_' . $i,
		array(
			'label'           => esc_html__( 'Select Trip ', 'travellable' ) . $i,
			'section'         => 'travellable_popular_destination_section',
			'settings'        => 'travellable_popular_destination_content_trip_' . $i,
			'active_callback' => 'travellable_is_popular_destination_section_and_content_type_trip_enabled',
			'type'            => 'select',
			'choices'         => travellable_get_trip_choices(),
		)
	);

	// Popular Destination - Select Trip Type.
	$wp_customize->add_setting(
		'travellable_popular_destination_content_trip_type_' . $i,
		array(
			'sanitize_callback' => 'absint',
		)
	);

	$wp_customize->add_control(
		'travellable_popular_destination_content_trip_type_' . $i,
		array(
			'label'           => esc_html__( 'Select Trip Type ', 'travellable' ) . $i,
			'section'         => 'travellable_popular_destination_section',
			'settings'        => 'travellable_popular_destination_content_trip_type_' . $i,
			'active_callback' => 'travellable_is_popular_destination_section_and_content_type_trip_type_enabled',
			'type'            => 'select',
			'choices'         => travellable_get_taxonomy_term_choices( 'itinerary_types' ),
		)
	);

	// Popular Destination - Select Destination.
	$wp_customize->add_setting(
		'travellable_popular_destination_content_destination_' . $i,
		array(
			'sanitize_callback' => 'absint',
		)
	);

	$wp_customize->add_control(
		'travellable_popular_destination_content_destination_' . $i,
		array(
			'label'           => esc_html__( 'Select Destination ', 'travellable' ) . $i,
			'section'         => 'travellable_popular_destination_section',
			'settings'        => 'travellable_popular_destination_content_destination_' . $i,
			'active_callback' => 'travellable_is_popular_destination_section_and_content_type_destination_enabled',
			'type'            => 'select',
			'choices'         => travellable_get_taxonomy_term_choices( 'travel_locations' ),
		)
	);

	// Popular Destination - Select Activity.
	$wp_customize->add_setting(
		'travellable_popular_destination_content_activity_' . $i,
		array(
			'sanitize_callback' => 'absint',
		)
	);

	$wp_customize->add_control(
		'travellable_popular_destination_content_activity_' . $i,
		array(
			'label'           => esc_html__( 'Select Activity ', 'travellable' ) . $i,
			'section'         => 'travellable_popular_destination_section',
			'settings'        => 'travellable_popular_destination_content_activity_' . $i,
			'active_callback' => 'travellable_is_popular_destination_section_and_content_type_activity_enabled',
			'type'            => 'select',
			'choices'         => travellable_get_taxonomy_term_choices( 'activity' ),
		)
	);

}

// Popular Destination - Button Label.
$wp_customize->add_setting(
	'travellable_popular_destination_button_label',
	array(
		'default'           => __( 'View all destinations', 'travellable' ),
		'sanitize_callback' => 'sanitize_text_field',
		'transport'         => 'refresh',
	)
);

$wp_customize->add_control(
	'travellable_popular_destination_button_label',
	array(
		'label'           => esc_html__( 'Button Label', 'travellable' ),
		'section'         => 'travellable_popular_destination_section',
		'settings'        => 'travellable_popular_destination_button_label',
		'type'            => 'text',
		'active_callback' => 'travellable_is_popular_destination_section_enabled',
	)
);



// Popular Destination - Button Link.
$wp_customize->add_setting(
	'travellable_popular_destination_button_link',
	array(
		'default'           => '',
		'sanitize_callback' => 'esc_url_raw',
		'transport'         => 'refresh',
	)
);

$wp_customize->add_control(
	'travellable_popular_destination_button_link',
	array(
		'label'           => esc_html__( 'Button Link', 'travellable' ),
		'section'         => 'travellable_popular_destination_section',
		'settings'        => 'travellable_popular_destination_button_link',
		'type'            => 'url',
		'active_callback' => 'travellable_is_popular_destination_section_enabled',
	)
);
