<?php
/**
 * Trending Package
 *
 * @package Travellable
 */

$wp_customize->add_section(
	'travellable_trending_package_section',
	array(
		'panel' => 'travellable_front_page_options',
		'title' => esc_html__( 'Trending Package', 'travellable' ),
	)
);

// Trending Package - Enable Section.
$wp_customize->add_setting(
	'travellable_enable_trending_package_section',
	array(
		'default'           => false,
		'sanitize_callback' => 'travellable_sanitize_switch',
	)
);

$wp_customize->add_control(
	new Travellable_Toggle_Switch_Custom_Control(
		$wp_customize,
		'travellable_enable_trending_package_section',
		array(
			'label'    => esc_html__( 'Enable Trending Package', 'travellable' ),
			'section'  => 'travellable_trending_package_section',
			'settings' => 'travellable_enable_trending_package_section',
		)
	)
);

if ( isset( $wp_customize->selective_refresh ) ) {
	$wp_customize->selective_refresh->add_partial(
		'travellable_enable_trending_package_section',
		array(
			'selector' => '#travellable_trending_package_section .section-link',
			'settings' => 'travellable_enable_trending_package_section',
		)
	);
}

// Trending Package - Section Title.
$wp_customize->add_setting(
	'travellable_trending_package_title',
	array(
		'default'           => __( 'Trending Packages', 'travellable' ),
		'sanitize_callback' => 'sanitize_text_field',
	)
);

$wp_customize->add_control(
	'travellable_trending_package_title',
	array(
		'label'           => esc_html__( 'Section Title', 'travellable' ),
		'section'         => 'travellable_trending_package_section',
		'settings'        => 'travellable_trending_package_title',
		'type'            => 'text',
		'active_callback' => 'travellable_is_trending_package_section_enabled',
	)
);

// Trending Package - Number of Posts.
$wp_customize->add_setting(
	'travellable_trending_package_count',
	array(
		'default'           => 6,
		'sanitize_callback' => 'absint',
	)
);

$wp_customize->add_control(
	'travellable_trending_package_count',
	array(
		'label'           => esc_html__( 'Number of posts to show', 'travellable' ),
		'section'         => 'travellable_trending_package_section',
		'settings'        => 'travellable_trending_package_count',
		'type'            => 'number',
		'input_attrs'     => array(
			'min' => 1,
			'max' => 12,
		),
		'active_callback' => 'travellable_is_trending_package_section_enabled',
	)
);

// Trending Package - Content Type.
$wp_customize->add_setting(
	'travellable_trending_package_content_type',
	array(
		'default'           => 'page',
		'sanitize_callback' => 'travellable_sanitize_select',
	)
);

$wp_customize->add_control(
	'travellable_trending_package_content_type',
	array(
		'label'           => esc_html__( 'Select Content Type', 'travellable' ),
		'section'         => 'travellable_trending_package_section',
		'settings'        => 'travellable_trending_package_content_type',
		'type'            => 'select',
		'active_callback' => 'travellable_is_trending_package_section_enabled',
		'choices'         => travellable_get_trending_package_content_type_choices(),
	)
);

// List out selected number of fields.
$trending_package_count = get_theme_mod( 'travellable_trending_package_count', 6 );
for ( $i = 1; $i <= $trending_package_count; $i++ ) {

	// Trending Package - Select Post.
	$wp_customize->add_setting(
		'travellable_trending_package_content_post_' . $i,
		array(
			'sanitize_callback' => 'absint',
		)
	);

	$wp_customize->add_control(
		'travellable_trending_package_content_post_' . $i,
		array(
			'label'           => esc_html__( 'Select Post ', 'travellable' ) . $i,
			'section'         => 'travellable_trending_package_section',
			'settings'        => 'travellable_trending_package_content_post_' . $i,
			'active_callback' => 'travellable_is_trending_package_section_and_content_type_post_enabled',
			'type'            => 'select',
			'choices'         => travellable_get_post_choices(),
		)
	);

	// Trending Package - Select Page.
	$wp_customize->add_setting(
		'travellable_trending_package_content_page_' . $i,
		array(
			'sanitize_callback' => 'absint',
		)
	);

	$wp_customize->add_control(
		'travellable_trending_package_content_page_' . $i,
		array(
			'label'           => esc_html__( 'Select Page ', 'travellable' ) . $i,
			'section'         => 'travellable_trending_package_section',
			'settings'        => 'travellable_trending_package_content_page_' . $i,
			'active_callback' => 'travellable_is_trending_package_section_and_content_type_page_enabled',
			'type'            => 'select',
			'choices'         => travellable_get_page_choices(),
		)
	);

	// Trending Package - Select Trip.
	$wp_customize->add_setting(
		'travellable_trending_package_content_trip_' . $i,
		array(
			'sanitize_callback' => 'absint',
		)
	);

	$wp_customize->add_control(
		'travellable_trending_package_content_trip_' . $i,
		array(
			'label'           => esc_html__( 'Select Trip ', 'travellable' ) . $i,
			'section'         => 'travellable_trending_package_section',
			'settings'        => 'travellable_trending_package_content_trip_' . $i,
			'active_callback' => 'travellable_is_trending_package_section_and_content_type_trip_enabled',
			'type'            => 'select',
			'choices'         => travellable_get_trip_choices(),
		)
	);

}
