<?php

/**
 * Sanitize select field
 *
 * @param  string $input   Selected input
 * @param  string $setting Input setting
 */
function travellable_sanitize_select( $input, $setting ) {
	// input must be a slug: lowercase alphanumeric characters, dashes and underscores are allowed only
	$input = sanitize_key( $input );

	// get the list of possible select options
	$choices = $setting->manager->get_control( $setting->id )->choices;

	// return input if valid or return default option
	return ( array_key_exists( $input, $choices ) ? $input : $setting->default );
}

/**
 * Sanitize multi-select field
 *
 * @param  string $input Selected input
 * @param  string $setting Input setting
 */
function travellable_sanitize_multi_select( $input, $setting ) {
	// if ( strpos( $input, ',' ) !== false) {
		$input = explode( ',', $input );
	// }

	// get the list of possible select options
	$choices = $setting->manager->get_control( $setting->id )->choices;

	foreach ( $input as $key => $value ) {
		if ( array_key_exists( $value, $choices ) ) {
			$data[ $key ] = $value;
		}
	}
	$data = implode( ',', $data );
	return $data;
}

/**
 * Sanitize checkbox field
 *
 * @param  string $input Selected input
 */
function travellable_sanitize_checkbox( $input ) {

	// returns true if checkbox is checked
	return ( ( isset( $input ) && true == $input ) ? true : false );
}

/**
 * Sanitize radio field
 *
 * @param  string $input Selected input
 * @param  string $setting Input setting
 */
function travellable_sanitize_radio( $input, $setting ) {

	// input must be a slug: lowercase alphanumeric characters, dashes and underscores are allowed only
	$input = sanitize_key( $input );

	// get the list of possible radio box options
	$choices = $setting->manager->get_control( $setting->id )->choices;

	// return input if valid or return default option
	return ( array_key_exists( $input, $choices ) ? $input : $setting->default );

}

function travellable_sanitize_google_fonts( $input, $setting ) {

	// Get list of choices from the control associated with the setting.
	$choices = $setting->manager->get_control( $setting->id )->choices;

	// If the input is a valid key, return it; otherwise, return the default.
	return ( array_key_exists( $input, $choices ) ? $input : $setting->default );

}

function travellable_sanitize_image( $image, $setting ) {
	/*
	 * Array of valid image file types.
	 *
	 * The array includes image mime types that are included in wp_get_mime_types()
	 */
	$mimes = array(
		'jpg|jpeg|jpe' => 'image/jpeg',
		'gif'          => 'image/gif',
		'png'          => 'image/png',
		'bmp'          => 'image/bmp',
		'tif|tiff'     => 'image/tiff',
		'ico'          => 'image/x-icon',
		'svg'          => 'image/svg+xml',
	);
	// Return an array with file extension and mime_type.
	$file = wp_check_filetype( $image, $mimes );
	// If $image has a valid mime_type, return it; otherwise, return the default.
	return ( $file['ext'] ? $image : $setting->default );
}

/**
 * Sanitize switch control
 *
 * @param  string   Switch value
 * @return integer  Sanitized value
 */
function travellable_sanitize_switch( $input ) {
	if ( true === $input ) {
		return true;
	} else {
		return false;
	}
}

function travellable_sanitize_sortable( $input ) {

	// Ensure $input is an array.
	if ( ! is_array( $input ) ) {
		$input = explode( ',', $input );
	}

	$output = array_map( 'sanitize_text_field', $input );

	return implode( ',', $output );
}

/**
 * Sanitize date time
 *
 * @param  string $input Date/Time string to be sanitized
 * @param  string $setting Input setting
 * @return string Sanitized input
 */
function travellable_sanitize_date_time( $input, $setting ) {
	$datetimeformat = 'Y-m-d';
	if ( $setting->manager->get_control( $setting->id )->include_time ) {
		$datetimeformat = 'Y-m-d H:i:s';
	}
	$date = DateTime::createFromFormat( $datetimeformat, $input );
	if ( $date === false ) {
		$date = DateTime::createFromFormat( $datetimeformat, $setting->default );
	}
	return $date->format( $datetimeformat );
}
