<?php

/**
 * Dynamic CSS
 */
function travellable_dynamic_css() {
	$default_color = travellable_get_default_color();

	$primary_color   = get_theme_mod( 'primary_color', $default_color['primary'] );
	$secondary_color = get_theme_mod( 'secondary_color', $default_color['secondary'] );

	$rgb  = travellable_convert_hex_to_rgb( $primary_color );
	$rgb2 = travellable_convert_hex_to_rgb( $secondary_color );

	$header_font           = get_theme_mod( 'travellable_header_font', 'EB Garamond' );
	$body_font             = get_theme_mod( 'travellable_body_font', 'Poppins' );
	$site_title_font       = get_theme_mod( 'travellable_site_title_font', 'EB Garamond' );
	$site_description_font = get_theme_mod( 'travellable_site_description_font', 'Poppins' );

	$custom_css  = '';
	$custom_css .= '
    /*Color Scheme*/
    :root {
        --bs-primary: ' . esc_attr( $primary_color ) . ';
        --bs-secondary: ' . esc_attr( $secondary_color ) . ';
        --bs-primary-rgb: ' . esc_attr( $rgb[0] ) . ', ' . esc_attr( $rgb[1] ) . ', ' . esc_attr( $rgb[2] ) . ';
        --bs-secondary-rgb: ' . esc_attr( $rgb2[0] ) . ', ' . esc_attr( $rgb2[1] ) . ', ' . esc_attr( $rgb2[2] ) . ';
    }

    a,
    .btn-link,
    .btn-primary:hover,
    .btn-primary:focus,
    .btn-secondary,
    .btn-outline-secondary:hover,
    .btn-outline-secondary:focus,
    .comment-reply-link-link,
    .comment-reply-link-outline-primary,
    .comment-reply-link-primary:hover,
    .comment-reply-link-primary:focus,
    .comment-reply-link-secondary,
    .comment-reply-link-outline-secondary:hover,
    .comment-reply-link-outline-secondary:focus,
    .trending-callout .slick-arrow,
    .start-price span,
    .prices,
    .btn-outline-primary,
    .trip-search-section .wp-travel-search p label,
    .trip-search-section .wp-travel-search p.wp-travel-search .button,
    aside .widget ul li:before,
    nav.pagination .nav-links .page-numbers,

    .wp-travel-default-article .wp-travel-entry-content-wrapper .description-right .trip-price
    {
    	color: ' . esc_attr( $primary_color ) . ';
    }

    .bg-primary,
    .overlay-primary:after,
    .btn-primary,
    .btn-primary:disabled,
    .btn-primary.disabled,
    button,
    input[type="button"],
    input[type="reset"],
    input[type="submit"],
    .header-top,
    .header-bottom,
    .main-slider-item:after,
    #nav-icon.open span,
    .btn-outline-primary:hover,
    .btn-outline-primary:focus,
    .comment-reply-link:hover,
    .comment-reply-link:focus,
    .comment-reply-link-primary,
    .comment-reply-link-outline-primary:hover,
    .comment-reply-link-outline-primary:focus,
    .why-callout:after,
    .newsletter-submit-btn:hover,
    .newsletter-submit-btn:focus,
    .site-footer,
    .scroll-to-top:hover,
    .scroll-to-top:focus,
    .wp-block-search .wp-block-search__button,
    nav.navigation.pagination .nav-links a:hover,
    nav.navigation.pagination .nav-links a:focus,
    nav.pagination .nav-links .page-numbers.current,

    .wp-travel-default-article .wp-travel-explore a:hover,
    .wp-travel-default-article .wp-travel-explore a:focus
    {
    	background-color: ' . esc_attr( $primary_color ) . ';
    }

    .btn-primary,
    .btn-primary:disabled,
    .btn-primary.disabled,
    .btn-outline-primary,
    .btn-outline-primary:hover,
    .btn-outline-primary:focus,
    .comment-reply-link,
    .comment-reply-link-primary,
    .comment-reply-link-outline-primary,
    .comment-reply-link-outline-primary:hover,
    .comment-reply-link-outline-primary:focus,
    .newsletter-submit-btn:hover,
    .newsletter-submit-btn:focus,
    nav.pagination .nav-links .page-numbers,

    .wp-travel-default-article .wp-travel-explore a
    {
    	border-color: ' . esc_attr( $primary_color ) . ';
    }

    .text-secondary,
    a:hover,
    a:focus,
    a:active,
    .btn-link:hover,
    .btn-link:focus,
    .btn-link.btn-link-light:hover,
    .btn-link.btn-link-light:focus,
    .btn-outline-secondary,
    .comment-reply-link-link:hover,
    .comment-reply-link-link:focus,
    .comment-reply-link-link-light:hover,
    .comment-reply-link-link-light:focus,
    .comment-reply-link-outline-secondary,
    .header-top a:hover,
    .header-top a:focus,
    .main-navigation .current_page_item > a,
    .main-navigation .current-menu-item > a,
    .main-navigation .current_page_ancestor > a,
    .main-navigation .current-menu-ancestor > a,
    .main-navigation li:hover > a,
    .main-navigation li.focus > a,
    .blog-callout .card-title a:hover,
    .blog-callout .card-title a:focus,
    .blog-callout .card-info a:hover,
    .blog-callout .card-info a:focus,
    .site-footer .site-footer-top a:hover,
    .site-footer .site-footer-top a:focus,
    .site-footer .site-footer-top .contact-details a:hover,
    .site-footer .site-footer-top .contact-details a:focus
    {
    	color: ' . esc_attr( $secondary_color ) . ';
    }

    .bg-secondary,
    .btn-secondary,
    .btn-secondary:hover,
    .btn-secondary:focus,
    .btn-primary:hover,
    .btn-primary:focus,
    .btn-outline-secondary:hover,
    .btn-outline-secondary:focus,
    .comment-reply-link-primary:hover,
    .comment-reply-link-primary:focus,
    .comment-reply-link-secondary,
    .comment-reply-link-secondary:hover,
    .comment-reply-link-secondary:focus,
    .comment-reply-link-outline-secondary:hover,
    .comment-reply-link-outline-secondary:focus,
    button:hover,
    button:focus,
    input[type="button"]:hover,
    input[type="button"]:focus,
    input[type="reset"]:hover,
    input[type="reset"]:focus,
    input[type="submit"]:hover,
    input[type="submit"]:focus,
    .main-slider .slick-arrow:hover,
    .main-slider .slick-arrow:focus,
    .slick-dots .slick-active button,
    .slick-dots button:hover,
    .slick-dots button:focus,
    .blog-callout .slick-dots li.slick-active button,
    .blog-callout .slick-dots li button:hover,
    .blog-callout .slick-dots li button:focus,
    .trip-search-section .wp-travel-search p.wp-travel-search .button:hover,
    .trip-search-section .wp-travel-search p.wp-travel-search .button:focus,
    .newsletter-submit-btn,
    .scroll-to-top,
    .wp-block-search .wp-block-search__button:focus,
    .wp-block-search .wp-block-search__button:hover
    {
    	background-color: ' . esc_attr( $secondary_color ) . ';
    }

    .btn-secondary,
    .btn-primary:hover,
    .btn-primary:focus,
    .btn-secondary:hover,
    .btn-secondary:focus,
    .btn-outline-secondary,
    .btn-outline-secondary:hover,
    .btn-outline-secondary:focus,
    .comment-reply-link-primary:hover,
    .comment-reply-link-primary:focus,
    .comment-reply-link-secondary,
    .comment-reply-link-secondary:hover,
    .comment-reply-link-secondary:focus,
    .comment-reply-link-outline-secondary,
    .comment-reply-link-outline-secondary:hover,
    .comment-reply-link-outline-secondary:focus,
    button:hover,
    button:focus,
    input[type="button"]:hover,
    input[type="button"]:focus,
    input[type="reset"]:hover,
    input[type="reset"]:focus,
    input[type="submit"]:hover,
    input[type="submit"]:focus,
    .main-slider .slick-arrow:hover,
    .main-slider .slick-arrow:focus,
    .slick-dots .slick-active button,
    .slick-dots button:hover,
    .slick-dots button:focus,
    .trip-search-section .wp-travel-search p.wp-travel-search .button:hover,
    .trip-search-section .wp-travel-search p.wp-travel-search .button:focus,
    .newsletter-submit-btn
    {
    	border-color: ' . esc_attr( $secondary_color ) . ';
    }

    @media (min-width: 1200px) {
        .main-navigation ul ul a {
            background-color: ' . esc_attr( $primary_color ) . ';
        }
        .main-navigation ul ul :hover > a,
        .main-navigation ul ul .focus > a {
            color: ' . esc_attr( $primary_color ) . ';
            background-color: ' . esc_attr( $secondary_color ) . ';
        }
    }
    @media (max-width: 1199.98px) {
        .main-navigation ul ul :hover > a,
        .main-navigation ul ul .focus > a {
            color: ' . esc_attr( $secondary_color ) . ';
        }
    }
    ';

	$custom_css .= '
	/*Fonts*/
	h1, h2, h3 {
	font-family: "' . esc_attr( $header_font ) . '", serif;
	}

	body,
	button, input, select, optgroup, textarea {
	font-family: "' . esc_attr( $body_font ) . '", serif;
	}

	.site-title a {
	font-family: "' . esc_attr( $site_title_font ) . '", serif;
	}

	.site-description {
	font-family: "' . esc_attr( $site_description_font ) . '", serif;
	}';

	wp_add_inline_style( 'travellable-style', $custom_css );
}
add_action( 'wp_enqueue_scripts', 'travellable_dynamic_css', 99 );

/**
 * Convert Hex to RGB
 *
 * @link http://bavotasan.com/2011/convert-hex-color-to-rgb-using-php/
 * @param  string Hex color
 * @return array RGB color
 */
function travellable_convert_hex_to_rgb( $hex ) {
	$hex = str_replace( '#', '', $hex );

	if ( strlen( $hex ) == 3 ) {
		$r = hexdec( substr( $hex, 0, 1 ) . substr( $hex, 0, 1 ) );
		$g = hexdec( substr( $hex, 1, 1 ) . substr( $hex, 1, 1 ) );
		$b = hexdec( substr( $hex, 2, 1 ) . substr( $hex, 2, 1 ) );
	} else {
		$r = hexdec( substr( $hex, 0, 2 ) );
		$g = hexdec( substr( $hex, 2, 2 ) );
		$b = hexdec( substr( $hex, 4, 2 ) );
	}
	$rgb = array( $r, $g, $b );

	return $rgb; // returns an array with the rgb values.
}
