<?php

if ( ! get_theme_mod( 'travellable_enable_banner_section', false ) ) {
	return;
}

$content_ids = $subtitle = $btn_label = $btn_link = $section_content = array();

$content_count = get_theme_mod( 'travellable_banner_slide_count', 3 );
$content_type  = get_theme_mod( 'travellable_banner_content', 'page' );

if ( ! in_array( $content_type, array( 'post', 'page' ) ) ) {
	return;
}

if ( 'post' === $content_type ) {
	for ( $i = 1; $i <= $content_count; $i++ ) {
		$item_id               = get_theme_mod( 'travellable_banner_content_post_' . $i );
		$content_ids[]         = $item_id;
		$subtitle[ $item_id ]  = get_theme_mod( 'travellable_banner_subtitle' . $i );
		$btn_label[ $item_id ] = get_theme_mod( 'travellable_banner_button_label' . $i, __( 'Read More', 'travellable' ) );
		$btn_link[ $item_id ]  = get_theme_mod( 'travellable_banner_button_link' . $i );
	}
} else {
	for ( $i = 1; $i <= $content_count; $i++ ) {
		$item_id               = get_theme_mod( 'travellable_banner_content_page_' . $i );
		$content_ids[]         = $item_id;
		$subtitle[ $item_id ]  = get_theme_mod( 'travellable_banner_subtitle' . $i );
		$btn_label[ $item_id ] = get_theme_mod( 'travellable_banner_button_label' . $i, __( 'Read More', 'travellable' ) );
		$btn_link[ $item_id ]  = get_theme_mod( 'travellable_banner_button_link' . $i );
	}
}


$args = array(
	'post_type'           => $content_type,
	'post__in'            => (array) $content_ids,
	'orderby'             => 'post__in',
	'posts_per_page'      => absint( $content_count ),
	'ignore_sticky_posts' => true,
);

$query = new WP_Query( $args );

if ( $query->have_posts() ) :
	while ( $query->have_posts() ) :
		$query->the_post();
		$data['id']            = get_the_ID();
		$data['title']         = get_the_title();
		$data['permalink']     = get_the_permalink();
		$data['thumbnail_url'] = get_the_post_thumbnail_url( get_the_ID(), 'full' );
		array_push( $section_content, $data );
	endwhile;
	wp_reset_postdata();

	$section_content = apply_filters( 'travellable_banner_section_content', $section_content );

	travellable_render_banner_section( $section_content, $subtitle, $btn_label, $btn_link );
endif;

function travellable_render_banner_section( $section_content, $subtitle, $btn_label, $btn_link ) {
	if ( empty( $section_content ) ) {
		return;
	}
	?>
	<section id="travellable_banner_section">
		<?php
		if ( is_customize_preview() ) :
			travellable_section_link( 'travellable_banner_section' );
		endif;
		?>
		<div class="main-slider">
			<?php
			foreach ( $section_content as $content ) {
				$item_id              = $content['id'];
				$btn_link[ $item_id ] = ! empty( $btn_link[ $item_id ] ) ? $btn_link[ $item_id ] : $content['permalink'];
				?>
				<div>
					<div class="main-slider-item " style="background-image: url('<?php echo esc_url( $content['thumbnail_url'] ); ?>');">
						<div class="container">
							<div class="main-slider-item-caption mt-xl-5">
								<div class="heading">
									<?php
									if ( $subtitle[ $item_id ] ) :
										echo '<h5 class="heading-sub text-light text-uppercase">' . esc_html( $subtitle[ $item_id ] ) . '</h5>';
									endif;
									?>
									<h2 class="display-1 heading-title"><?php echo esc_html( $content['title'] ); ?></h2>
								</div>
								<?php if ( $btn_label[ $item_id ] ) : ?>
									<div class="btns-row pt-3">
										<a href="<?php echo esc_url( $btn_link[ $item_id ] ); ?>" class="btn btn-outline-light btn-lg"><?php echo esc_html( $btn_label[ $item_id ] ); ?> <em class="bi bi-chevron-right"></em></a>
									</div>
								<?php endif; ?>
							</div><!-- .main-slideer-item-caption -->
						</div>
					</div><!-- .main-slider-item  -->
				</div>
				<?php
			}
			?>
		</div>
	</section>
	<?php
}
