<?php
if ( ! get_theme_mod( 'travellable_enable_popular_destination_section', false ) ) {
	return;
}

$section_title = get_theme_mod( 'travellable_popular_destination_title', __( 'Destinations', 'travellable' ) );
$button_label  = get_theme_mod( 'travellable_popular_destination_button_label', __( 'View all destinations', 'travellable' ) );
$button_link   = get_theme_mod( 'travellable_popular_destination_button_link' );
$button_link   = ! empty( $button_link ) ? $button_link : '#';

$content_type = get_theme_mod( 'travellable_popular_destination_content_type', 'page' );

switch ( $content_type ) {
	case 'post': // Post.
		$content_ids = array();
		for ( $i = 1; $i <= 5; $i++ ) {
			$content_post_id = get_theme_mod( 'travellable_popular_destination_content_post_' . $i );
			if ( ! empty( $content_post_id ) ) {
				$content_ids[] = $content_post_id;
			}
		}

		$args = array(
			'post_type'      => 'post',
			'posts_per_page' => 5,
			'post__in'       => (array) $content_ids,
			'order_by'       => 'post__in',
		);

		$section_content = array();
		$query           = new WP_Query( $args );
		if ( $query->have_posts() ) :
			while ( $query->have_posts() ) :
				$query->the_post();
				$data['title']         = get_the_title();
				$data['permalink']     = get_the_permalink();
				$data['thumbnail_url'] = get_the_post_thumbnail_url( get_the_ID(), 'full' );
				array_push( $section_content, $data );
			endwhile;
			wp_reset_postdata();
		endif;

		break;

	case 'page': // Page.
		$content_ids = array();
		for ( $i = 1; $i <= 5; $i++ ) {
			$content_post_id = get_theme_mod( 'travellable_popular_destination_content_page_' . $i );
			if ( ! empty( $content_post_id ) ) {
				$content_ids[] = $content_post_id;
			}
		}

		$args = array(
			'post_type'      => 'page',
			'posts_per_page' => 5,
			'post__in'       => (array) $content_ids,
			'order_by'       => 'post__in',
		);

		$section_content = array();
		$query           = new WP_Query( $args );
		if ( $query->have_posts() ) :
			while ( $query->have_posts() ) :
				$query->the_post();
				$data['title']         = get_the_title();
				$data['permalink']     = get_the_permalink();
				$data['thumbnail_url'] = get_the_post_thumbnail_url( get_the_ID(), 'full' );
				array_push( $section_content, $data );
			endwhile;
			wp_reset_postdata();
		endif;

		break;

	case 'itineraries': // Trip.
		if ( ! class_exists( 'WP_Travel' ) ) {
			return;
		}

		$content_ids = array();
		for ( $i = 1; $i <= 5; $i++ ) {
			$content_post_id = get_theme_mod( 'travellable_popular_destination_content_trip_' . $i );
			if ( ! empty( $content_post_id ) ) {
				$content_ids[] = $content_post_id;
			}
		}

		$args = array(
			'post_type'      => 'itineraries',
			'posts_per_page' => 5,
			'post__in'       => (array) $content_ids,
			'orderby'        => 'post__in',
		);

		$section_content = array();
		$query           = new WP_Query( $args );
		if ( $query->have_posts() ) :
			while ( $query->have_posts() ) :
				$query->the_post();
				$data['title']         = get_the_title();
				$data['permalink']     = get_the_permalink();
				$data['thumbnail_url'] = get_the_post_thumbnail_url( get_the_ID(), 'full' );
				array_push( $section_content, $data );
			endwhile;
			wp_reset_postdata();
		endif;

		break;

	default:
		break;
}
?>

<section id="travellable_popular_destination_section" class="destination-callout">
	<?php
	if ( is_customize_preview() ) :
		travellable_section_link( 'travellable_popular_destination_section' );
	endif;
	?>
	<div class="container">
		<div class="row align-items-center justify-content-center">
			<div class="col-lg-6 mb-5 order-lg-1">
				<div class="heading text-center">
					<h2 class="title"><?php echo esc_html( $section_title ); ?></h2>
					<?php if ( ! empty( $button_label ) ) : ?>
						<a class="btn btn-link text-uppercase" href="<?php echo esc_url( $button_link ); ?>"><em class="bi bi-arrow-right fs-3 align-middle me-2"></em><?php echo esc_html( $button_label ); ?></a>
					<?php endif; ?>
				</div>
			</div>
			<div class="col-lg-3 col-md-6 mb-5 order-lg-0">
				<?php if ( isset( $section_content[0] ) ) : ?>
					<div class="card bg-dark">
						<a class="text-white d-block" href="<?php echo esc_url( $section_content[0]['permalink'] ); ?>"><img alt="<?php echo esc_attr( $section_content[0]['title'] ); ?>" class="card-img" src="<?php echo esc_url( $section_content[0]['thumbnail_url'] ); ?>">
							<div class="card-img-overlay">
								<h4 class="card-title text-light"><?php echo esc_html( $section_content[0]['title'] ); ?></h4>
							</div>
						</a>
					</div>
				<?php endif; ?>
			</div>
			<div class="col-lg-3 col-md-6 mb-5 order-lg-2">
				<?php if ( isset( $section_content[1] ) ) : ?>
					<div class="card bg-dark">
						<a class="text-white d-block" href="<?php echo esc_url( $section_content[1]['permalink'] ); ?>"><img alt="<?php echo esc_attr( $section_content[1]['title'] ); ?>" class="card-img" src="<?php echo esc_url( $section_content[1]['thumbnail_url'] ); ?>">
							<div class="card-img-overlay">
								<h4 class="card-title text-light"><?php echo esc_html( $section_content[1]['title'] ); ?></h4>
							</div>
						</a>
					</div>
				<?php endif; ?>
			</div>

			<?php if ( isset( $section_content[2] ) ) : ?>
				<div class="col-lg-4 col-md-6 mb-5 order-lg-3">
					<div class="card bg-dark">
						<a class="text-white d-block" href="<?php echo esc_url( $section_content[2]['permalink'] ); ?>"><img alt="<?php echo esc_attr( $section_content[2]['title'] ); ?>" class="card-img" src="<?php echo esc_url( $section_content[2]['thumbnail_url'] ); ?>">
							<div class="card-img-overlay">
								<h4 class="card-title text-light"><?php echo esc_html( $section_content[2]['title'] ); ?></h4>
							</div>
						</a>
					</div>
				</div>
			<?php endif; ?>

			<?php if ( isset( $section_content[3] ) ) : ?>
				<div class="col-lg-4 col-md-6 mb-5 order-lg-4">
					<div class="card bg-dark">
						<a class="text-white d-block" href="<?php echo esc_url( $section_content[3]['permalink'] ); ?>"><img alt="<?php echo esc_attr( $section_content[3]['title'] ); ?>" class="card-img" src="<?php echo esc_url( $section_content[3]['thumbnail_url'] ); ?>">
							<div class="card-img-overlay">
								<h4 class="card-title text-light"><?php echo esc_html( $section_content[3]['title'] ); ?></h4>
							</div>
						</a>
					</div>
				</div>
			<?php endif; ?>

			<?php if ( isset( $section_content[4] ) ) : ?>
				<div class="col-lg-4 col-md-6 mb-5 order-lg-5">
					<div class="card bg-dark">
						<a class="text-white d-block" href="<?php echo esc_url( $section_content[4]['permalink'] ); ?>"><img alt="<?php echo esc_attr( $section_content[4]['title'] ); ?>" class="card-img" src="<?php echo esc_url( $section_content[4]['thumbnail_url'] ); ?>">
							<div class="card-img-overlay">
								<h4 class="card-title text-light"><?php echo esc_html( $section_content[4]['title'] ); ?></h4>
							</div>
						</a>
					</div>
				</div>
			<?php endif; ?>
		</div>
	</div>
</section>
