<?php
if ( ! get_theme_mod( 'travellable_enable_trending_package_section', false ) ) {
	return;
}

$section_content = array();
$post_count      = get_theme_mod( 'travellable_trending_package_count', 6 );
$content_type    = get_theme_mod( 'travellable_trending_package_content_type', 'page' );

switch ( $content_type ) {
	case 'post': // Post.
		$content_ids = array();
		for ( $i = 1; $i <= $post_count; $i++ ) {
			$content_post_id = get_theme_mod( 'travellable_trending_package_content_post_' . $i );
			if ( ! empty( $content_post_id ) ) {
				$content_ids[] = $content_post_id;
			}
		}

		$args = array(
			'post_type'      => 'post',
			'posts_per_page' => $post_count,
			'post__in'       => (array) $content_ids,
			'order_by'       => 'post__in',
		);

		break;

	case 'page': // Page.
		$content_ids = array();
		for ( $i = 1; $i <= $post_count; $i++ ) {
			$content_post_id = get_theme_mod( 'travellable_trending_package_content_page_' . $i );
			if ( ! empty( $content_post_id ) ) {
				$content_ids[] = $content_post_id;
			}
		}

		$args = array(
			'post_type'      => 'page',
			'posts_per_page' => $post_count,
			'post__in'       => (array) $content_ids,
			'order_by'       => 'post__in',
		);

		break;

	case 'itineraries': // Trip.
		if ( ! class_exists( 'WP_Travel' ) ) {
			return;
		}

		$content_ids = array();
		for ( $i = 1; $i <= $post_count; $i++ ) {
			$content_post_id = get_theme_mod( 'travellable_trending_package_content_trip_' . $i );
			if ( ! empty( $content_post_id ) ) {
				$content_ids[] = $content_post_id;
			}
		}

		$args = array(
			'post_type'      => 'itineraries',
			'posts_per_page' => $post_count,
			'post__in'       => (array) $content_ids,
			'orderby'        => 'post__in',
		);

		break;

	default:
		break;
}

$query = new WP_Query( $args );
if ( $query->have_posts() ) :
	while ( $query->have_posts() ) :
		$query->the_post();
		$data['id']            = get_the_ID();
		$data['title']         = get_the_title();
		$data['permalink']     = get_the_permalink();
		$data['thumbnail_url'] = get_the_post_thumbnail_url( get_the_ID() );
		array_push( $section_content, $data );
	endwhile;
	wp_reset_postdata();
endif;

$section_content = apply_filters( 'travellable_trending_package_section_content', $section_content );

travellable_render_trending_package_section( $section_content );

/**
 * Render product section
 */
function travellable_render_trending_package_section( $section_content ) {
	?>
	<section id="travellable_trending_package_section" class="trending-callout">
		<?php
		if ( is_customize_preview() ) :
			travellable_section_link( 'travellable_trending_package_section' );
		endif;

		$section_title = get_theme_mod( 'travellable_trending_package_title', __( 'Trending Packages', 'travellable' ) );
		$content_type  = get_theme_mod( 'travellable_trending_package_content_type', 'page' );
		?>
		<div class="container">
			<div class="row mb-5">
				<div class="col-12">
					<div class="heading text-center">
						<h2 class=" heading-title fw-normal"><?php echo esc_html( $section_title ); ?></h2>
					</div>
					<!-- Heading -->
				</div>
			</div>
			<!-- Row -->
			<div class="row">
				<?php
				foreach ( $section_content as $content ) {
					?>
					<div class="col-lg-4 col-md-6">
						<div class="card bg-dark text-white mb-5">
							<a href="<?php echo esc_url( $content['permalink'] ); ?>" class="d-block">
								<img src="<?php echo esc_url( $content['thumbnail_url'] ); ?>" class="card-img" alt="<?php echo esc_attr( $content['title'] ); ?>">
								<div class="card-img-overlay text-light ps-4">
									<h5 class="card-title text-light"><?php echo esc_html( $content['title'] ); ?></h5>
									<?php if ( 'itineraries' === $content_type ) { ?>
										<div class="row align-items-center">
											<div class="col">
												<?php wptravel_get_trip_duration( $content['id'] ); ?>
											</div>
											<div class="col justify-content-end">
												<div class="start-price">
													<?php wptravel_trip_price( $content['id'], true ); ?>
												</div>
											</div>
										</div>
									<?php } ?>
								</div>
							</a>
						</div>
					</div>
					<?php
				}
				?>
			</div>
		</div>
	</section>
	<?php
}
